.. _geom:

*******************************
Geometry handling (`sisl.geom`)
*******************************

.. module:: sisl.geom

The `~sisl.Geometry` class is the workhorse of basically
all computational details of large parts of `sisl`.
It defines atomic species, coordinates, associated orbitals
and much more. Therefore an extended suite of tools and methods
are available to handle this complex object.


.. toctree::
   :maxdepth: 2

   building

.. toctree::
   :maxdepth: 1

   neighbors
